"""
URL configuration for django_package_app project.

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/4.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, re_path, include
from django.conf import settings

from drf_yasg.views import get_schema_view
from drf_yasg import openapi


schema_view = get_schema_view(
    openapi.Info(
        title="Django Package Boilerplate API",
        default_version="v1",
        description="Django Package Boilerplate API Documents",
    ),
    public=True,
)


urlpatterns = [
    path('admin/', admin.site.urls),
    path('django_package_app/', include('django_package_boilerplate.urls')),
]

if settings.DEBUG:
    urlpatterns += [
        re_path(r'^swagger(?P<format>\.json|\.yaml)$', schema_view.without_ui(cache_timeout=0), name="schema-json"),
        re_path(r'^swagger/$', schema_view.with_ui('swagger', cache_timeout=0), name='schema-swagger-ui'),
        re_path(r'^redoc/$', schema_view.with_ui('redoc', cache_timeout=0), name='schema-redoc')
    ]






# Django Rest Framework
from rest_framework import serializers

# App
from django_package_boilerplate.models import ModelName


# Classes
class ModelNameSerializer(serializers.ModelSerializer):

    class Meta:
        model = ModelName
        fields = ['title', 'created_at', 'updated_at']



# Django
from django.db import models


# Class Section
class BaseModel(models.Model):

    # Basic
    title = models.TextField('제목', blank=True, null=True)

    # Dates
    created_at = models.DateTimeField('생성일자', auto_now_add=True, null=True)
    updated_at = models.DateTimeField('수정일자', auto_now=True, null=True)

    class Meta:
        abstract = True

    def __str__(self):
        return '{}({})'.format(self.title, self.id)


class ModelName(BaseModel):

    class Meta:
        verbose_name = 'model_name'
        verbose_name_plural = 'model_names'
        ordering = ['-created_at']



from django.urls import path
from rest_framework.routers import DefaultRouter

# App
from django_package_boilerplate.views import ModelNameViewSet


# Variables
router = DefaultRouter()
router.register(r'model_names', ModelNameViewSet, basename='model_name')
urlpatterns = router.urls

urlpatterns += [
    # path('search', views.SearchView, name='regions'),
]
